import Vue from 'vue';
import { format, addMonths, isSameMonth, isAfter, startOfMonth, lastDayOfMonth, addDays, differenceInCalendarDays, startOfWeek } from 'date-fns';
import { _ as __vue_normalize__ } from '../normalize-component-ea49d1b5.js';

var script = Vue.extend({
    name: "Calendar",
    props: ["disableBefore"],
    data: function () {
        return {
            selectedMonth: new Date()
        };
    },
    methods: {
        format: function (date, pattern) {
            return format(date, pattern);
        },
        next: function () {
            this.selectedMonth = addMonths(this.selectedMonth, 1);
        },
        prev: function () {
            this.selectedMonth = addMonths(this.selectedMonth, -1);
        },
        sameMonth: function (d) {
            return isSameMonth(d, this.selectedMonth);
        },
        isEnable: function (d) {
            if (!this.disableBefore) {
                return true;
            }
            return isAfter(d, this.disableBefore);
        }
    },
    computed: {
        weeks: function () {
            var startmonth = startOfMonth(this.selectedMonth);
            var endmonth = lastDayOfMonth(this.selectedMonth);
            var start = addDays(startmonth, differenceInCalendarDays(startOfWeek(startmonth, { weekStartsOn: 1 }), startmonth));
            var weeks = [[], [], [], [], [], []];
            var lastday = start;
            for (var i = 0; i < 6; i++) {
                var week = weeks[i];
                for (var j = 0; j <= 6; j++) {
                    week.push({
                        date: lastday,
                        show: this.sameMonth(lastday)
                    });
                    lastday = addDays(lastday, 1);
                }
            }
            return weeks;
        }
    }
});

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      directives: [
        {
          name: "twclass",
          rawName: "v-twclass",
          value: "flex flex-col bg-white shadow border w-full",
          expression: "'flex flex-col bg-white shadow border w-full'"
        }
      ]
    },
    [
      _c(
        "div",
        {
          directives: [
            {
              name: "twclass",
              rawName: "v-twclass",
              value: "flex",
              expression: "'flex'"
            }
          ]
        },
        [
          _c(
            "button",
            {
              directives: [
                {
                  name: "twclass",
                  rawName: "v-twclass",
                  value: "text-left w-1/6 p-4",
                  expression: "'text-left w-1/6 p-4'"
                }
              ],
              on: { click: _vm.prev }
            },
            [_vm._v("\n            prev\n        ")]
          ),
          _vm._v(" "),
          _c(
            "h2",
            {
              directives: [
                {
                  name: "twclass",
                  rawName: "v-twclass",
                  value: "w-2/3 text-center p-4",
                  expression: "'w-2/3 text-center p-4'"
                }
              ]
            },
            [
              _vm._v(
                "\n            " +
                  _vm._s(_vm.format(_vm.selectedMonth, "MMM yyyy")) +
                  "\n        "
              )
            ]
          ),
          _vm._v(" "),
          _c(
            "button",
            {
              directives: [
                {
                  name: "twclass",
                  rawName: "v-twclass",
                  value: "w-1/6 text-right p-4",
                  expression: "'w-1/6 text-right p-4'"
                }
              ],
              on: { click: _vm.next }
            },
            [_vm._v("\n            next\n        ")]
          )
        ]
      ),
      _vm._v(" "),
      _c(
        "ul",
        {
          directives: [
            {
              name: "twclass",
              rawName: "v-twclass",
              value: "flex flex-col",
              expression: "'flex flex-col'"
            }
          ]
        },
        [
          _c(
            "ul",
            {
              directives: [
                {
                  name: "twclass",
                  rawName: "v-twclass",
                  value: "flex",
                  expression: "'flex'"
                }
              ]
            },
            _vm._l(_vm.weeks[0], function(day) {
              return _c(
                "li",
                {
                  directives: [
                    {
                      name: "twclass",
                      rawName: "v-twclass",
                      value: "w-1/6 m-3 text-center",
                      expression: "'w-1/6 m-3 text-center'"
                    }
                  ],
                  key: day.date.getTime()
                },
                [
                  _vm._v(
                    "\n                " +
                      _vm._s(_vm.format(day.date, "EEEE")) +
                      "\n            "
                  )
                ]
              )
            }),
            0
          ),
          _vm._v(" "),
          _vm._l(_vm.weeks, function(week) {
            return _c("li", { key: week[0].date.getTime() }, [
              _c(
                "ul",
                {
                  directives: [
                    {
                      name: "twclass",
                      rawName: "v-twclass",
                      value: "flex",
                      expression: "'flex'"
                    }
                  ]
                },
                _vm._l(week, function(d) {
                  return _c(
                    "li",
                    {
                      directives: [
                        {
                          name: "twclass",
                          rawName: "v-twclass",
                          value: "w-1/6 m-3 text-center",
                          expression: "'w-1/6 m-3 text-center'"
                        }
                      ],
                      key: d.date.getTime()
                    },
                    [
                      d.show
                        ? _c(
                            "button",
                            {
                              directives: [
                                {
                                  name: "twclass",
                                  rawName: "v-twclass",
                                  value: {
                                    "p-3": true,
                                    "rounded-full": true,
                                    "cursor-pointer": _vm.isEnable(d.date),
                                    "cursor-not-allowed": !_vm.isEnable(d.date),
                                    "hover:bg-primary": _vm.isEnable(d.date),
                                    "text-textLight": !_vm.isEnable(d.date)
                                  },
                                  expression:
                                    "{\n                            'p-3': true,\n                            'rounded-full': true,\n                            'cursor-pointer': isEnable(d.date),\n                            'cursor-not-allowed': !isEnable(d.date),\n                            'hover:bg-primary': isEnable(d.date),\n                            'text-textLight': !isEnable(d.date)\n                        }"
                                }
                              ],
                              attrs: { disabled: !_vm.isEnable(d.date) },
                              on: {
                                click: function($event) {
                                  return _vm.$emit("change", {
                                    selected: d.date
                                  })
                                }
                              }
                            },
                            [
                              _vm._v(
                                "\n                        " +
                                  _vm._s(_vm.format(d.date, "dd")) +
                                  "\n                    "
                              )
                            ]
                          )
                        : _vm._e()
                    ]
                  )
                }),
                0
              )
            ])
          })
        ],
        2
      )
    ]
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = __vue_normalize__(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

export default __vue_component__;
